// ***************************************************************************************

// THIS DO FILE CONTAINS STATA COMMANDS TO REPLICATE THE RESULTS IN 
/// HNATKOVSKA, LAHIRI, PAUL (2011) paper "CASTES AND LABOR MOBILITY"

// please cite as 
// Hnatkovska, Viktoria, Amartya Lahiri, and Sourabh B. Paul (2011) "Castes and Labor Mobility," American Economic Journal: Applied Economics, forthcoming

// USE THIS FILE TO OBTAIN TABLES 6 AND 8 IN THE TEXT

*************************************************************************************** //




//  BOOTSTRAP FOR OAXACA DECOMPOSITION 
* TO BE USED TOGETHER WITH 20110156-statadofile.do FILE
* run all the sample selection commands from there first;
* use this file for performing Oaxaca-Blinder decomposition of SC/ST wage and consumption gaps over 1983-2005 period
* as well as for bootstrapping std errors in this decomposition


****** CREATE STRATAs AND CLUSTERs
* this is needed to account for complex sample design of NSS data

/* Create unique cluster id and stratum id(we DO NOT include sub-sample and sub-round structure).
   We consider ONLY first stage stratification. The stratification within each fsu(i.e. village/urban block) is ignored here.*/
gen cluster_id =.  //clustering: each fsu is one cluster
gen stratum_id =.  //stratification
//generate unique id for each round separately since stratification structure is different
//For round 38
	// Make sure that the "group" command below has all vriables so that cluster and stratum are uniquely defined
	egen temp=group( sector state_old region stratum fsu) if round==38 
	replace cluster_id = temp if round == 38
	drop temp
	egen temp=group( sector state_old region stratum) if round == 38
	replace stratum_id= temp if round == 38
	drop temp
//For round 61 
	//Merge stratification information of 61 round (need district, sub-strata variable)
	sort round fsu
	merge m:1 round fsu using "C:\data10\caste_mobility\stata\INTERGEN\61_stratification.dta"
	drop _merge
	egen temp=group( state_old district stratum sub_stratum fsu) if round==61  
	replace cluster_id = temp if round == 61
	drop temp
	egen temp=group( state_old district stratum sub_stratum) if round == 61
	replace stratum_id= temp if round == 61
	drop temp

		
//If there are any strata with only one PSU (cluster), bootsrap sampling with cluster structure will not be valid.
//There are two solutions - 1) drop all singleton strata, 2) merge sigleton strata with geigraphically neighbouring strata - i.e., with same sector, state and region.
//We choose the first option. For second option, we need to manually inspect and reassign stratum number to singleton strata.
// Ref: http://www.stata.com/support/faqs/stat/stratum.html

//Inspect sigleton strata
pause on
keep if round==38 | round==61 //ONLY 38 AND 61 ROUND
levelsof round, local(round)
foreach r of local round {
	preserve
		keep if round==`r'
		svyset  cluster_id [pw=mul4], strata( stratum_id)
		svydes   //look for stratum number with asterisk (*) in the column named "#Units". These strata have one PSU.
		//pause
		//drop singleton strata
		*ssc inst unique
		unique cluster_id, by( stratum_id ) gen(dup) //find number of unique cluster in each stratum
		tab  stratum_id if dup==1  //tabulate singleton strata
		by stratum_id, sort: egen temp = total(dup)
		drop if temp ==1  //drop all singleton strata
		drop temp dup
		sort round
		save "${wk_dir}/bootstrap_round`r'.dta", replace
	restore
}

//Merge all rounds after deleting sigleton strata
clear
use "${wk_dir}/bootstrap_round38.dta", clear
foreach r in 61 {
	merge m:m round using "${wk_dir}/bootstrap_round`r'.dta"
	drop _merge
	sort round
	//erase "${wk_dir}/bootstrap_round`r'.dta"
}
//erase "${wk_dir}/bootstrap_round38.dta"




log using oaxacaboot_wages_HLP_AEJ, text replace
**********************  BOOTSTRAPPING  WAGES **********************
* SETTING THINGS UP

** Generate unique cluster and strata id for pooled cross section (http://www.stata.com/statalist/archive/2008-10/msg00521.html)
egen pooled_cid = group(cluster_id round)
egen pooled_sid = group(stratum_id round)

svyset  pooled_cid [pw=mul4], strata( pooled_sid)
bsweights bsw, reps(100) n(-1)  //change reps(#) to desired number of resampling
//survey set using bootstrap resampling weight variables
svyset  pooled_cid [pw=mul4], strata( pooled_sid) bsrweight(bsw*) vce(bootstrap)
//bootstrap using survey setting and bootstrap resampling weights


* MEAN
svy bootstrap   e(edu_dum_e1)	e(quota_scst_e1) e(total_d1)	e(total_e1)		e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	    e(total_c2)	  e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)		e(total_dc)		e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelch lwage_usual age age2 sector1 muslim edu_dum2-edu_dum5 zone_dum1-zone_dum5 quota_scst /// 
	if (wage_smplip==1 | wage_smplic==1), group(hh_groupSCST2) time(round) timept(38 61) 

* QUANTILES
local r=0.1
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrif lwage_usual age age2 sector1 muslim edu_dum2-edu_dum5 zone_dum1-zone_dum5 quota_scst /// 
	if (wage_smplip==1 | wage_smplic==1), group(hh_groupSCST2) time(round) timept(38 61) q(`r')

local r=0.5
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrif lwage_usual age age2 sector1 muslim edu_dum2-edu_dum5 zone_dum1-zone_dum5 quota_scst /// 
	if (wage_smplip==1 | wage_smplic==1), group(hh_groupSCST2) time(round) timept(38 61) q(`r')

local r=0.9
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrif lwage_usual age age2 sector1 muslim edu_dum2-edu_dum5 zone_dum1-zone_dum5 quota_scst /// 
	if (wage_smplip==1 | wage_smplic==1), group(hh_groupSCST2) time(round) timept(38 61) q(`r')

drop bsw*
log close



log using oaxacaboot_cons_HLP_AEJ, text replace
**********************  BOOTSTRAPPING  CONSUMPTION **********************
svyset  pooled_cid [pw=hh_mul4], strata( pooled_sid)
bsweights bsw, reps(100) n(-1)  //change reps(#) to desired number of resampling
//survey set using bootstrap resampling weight variables
svyset  pooled_cid [pw=hh_mul4], strata( pooled_sid) bsrweight(bsw*) vce(bootstrap)
//bootstrap using survey setting and bootstrap resampling weights


* MEAN
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelchc.dta", replace): /// 
	mysmithwelchC lmpced sector1 head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 muslim hh_size2 earning_mem zone_dum1-zone_dum5 quota_scst /// 
	if (overall_smplic==1 | overall_smplip==1) & reln_head==1, group(hh_groupSCST2) time(round) timept(38 61) 

* QUANTILES
local r=0.1
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrifC lmpced sector1 head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 muslim hh_size2 earning_mem zone_dum1-zone_dum5 quota_scst /// 
	if (overall_smplic==1 | overall_smplip==1) & reln_head==1, group(hh_groupSCST2) time(round) timept(38 61) q(`r')

local r=0.5
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrifC lmpced sector1 head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 muslim hh_size2 earning_mem zone_dum1-zone_dum5 quota_scst /// 
	if (overall_smplic==1 | overall_smplip==1) & reln_head==1, group(hh_groupSCST2) time(round) timept(38 61) q(`r')

local r=0.9
svy bootstrap e(edu_dum_e1)	e(quota_scst_e1)	e(total_d1)	e(total_e1)	e(total_c1)	e(edu_dum_e2)	e(quota_scst_e2)	/// 
	e(total_d2)	e(total_e2)	e(total_c2)	e(edu_dum_de)	e(quota_scst_de)	e(total_dd)	e(total_de)	e(total_dc)	e(edu_dum_de_e)	/// 
	e(quota_scst_de_e)	e(total_de_d)	e(total_de_e)	e(total_de_c), saving("${wk_dir}/bootstrap_smithwelch.dta", replace): /// 
	mysmithwelchrifC lmpced sector1 head_edu_dum2-head_edu_dum5 max_edu_dum2-max_edu_dum5 muslim hh_size2 earning_mem zone_dum1-zone_dum5 quota_scst /// 
	if (overall_smplic==1 | overall_smplip==1) & reln_head==1, group(hh_groupSCST2) time(round) timept(38 61) q(`r')
	

drop bsw*

log close



****************************************************************************				
****** USER DEFINED SMITHWELCH PROGRAM TO BE USED FOR BOOTSTRAPPING ********	
			* MEAN WAGES
capture program drop mysmithwelch
program mysmithwelch, eclass properties(svyb)
	version 11
	syntax varlist [pweight iweight] [if] [in], GROUPvar(varname numeric) TIMEvar(varname numeric) TIMEPTs(numlist min=2 max=2 integer ascending)

	*Check whether "group" variable is in proper format
	qui levelsof `groupvar', local(gr)
	local gg=0
	foreach i of local gr {
		if(`i'!=`gg'  | `gg'>1) {
			di in red "The group variable should be 0/1"
			exit 198
		}
		local ++gg
	}
	
	*sample selection
	marksample touse

	*run model for each round and each group
	qui foreach i of local timepts {
		levelsof `groupvar', local(gr)
		foreach j of local gr {
			regress `varlist' [pw `exp'] if `touse' & `timevar'==`i' & `groupvar'==`j', robust
			devcon , groups(edu_dum1-edu_dum5, zone_dum1-zone_dum6) 
			estimates store m_`j'_`i'
		}
		regress `varlist' `groupvar' [pw `exp'] if `touse' & `timevar'==`i', robust
		devcon , groups(edu_dum1-edu_dum5, zone_dum1-zone_dum6)  
		estimates store m_pooled_`i'

	}

smithwelch m_0_38 m_1_38 m_0_61 m_1_61, benchmark(1) reference(m_pooled_38 m_pooled_61) adjust(`groupvar') detail(age_both=age age2, edu_dum=edu_dum*, zone_dum=zone_dum*) 

	
	//ereturn
*clear all e() first
ereturn clear

	
 matrix D = r(D)
 matrix DD = r(DD)
 *Sample 1
 ereturn scalar edu_dum_e1=el(D,2,2)
 ereturn scalar quota_scst_e1=el(D,6,2)
 ereturn scalar total_d1=el(D,8,1)
 ereturn scalar total_e1=el(D,8,2)
 ereturn scalar total_c1=el(D,8,3)
 
 *Sample 2
 ereturn scalar edu_dum_e2=el(D,2,6)
 ereturn scalar quota_scst_e2=el(D,6,6)
 ereturn scalar total_d2=el(D,8,5)
 ereturn scalar total_e2=el(D,8,6)
 ereturn scalar total_c2=el(D,8,7)
 
*Sample 2 minus Sample 1
 matrix AA = D[1...,"s2:"]-D[1...,"s1:"] 	
 ereturn scalar edu_dum_de=el(AA,2,2)
 ereturn scalar quota_scst_de=el(AA,6,2)
 ereturn scalar total_dd=el(AA,8,1)
 ereturn scalar total_de=el(AA,8,2)
 ereturn scalar total_dc=el(AA,8,3)

 *Decomp of dE
 ereturn scalar edu_dum_de_e=el(DD,2,2)
 ereturn scalar quota_scst_de_e=el(DD,6,2)
 ereturn scalar total_de_d=el(DD,8,1)
 ereturn scalar total_de_e=el(DD,8,2)
 ereturn scalar total_de_c=el(DD,8,3)
 

end

*** ====================================================================================================================

			* MEAN CONSUMPTION
capture program drop mysmithwelchC
program mysmithwelchC, eclass properties(svyb)
	version 11
	syntax varlist [pweight iweight] [if] [in], GROUPvar(varname numeric) TIMEvar(varname numeric) TIMEPTs(numlist min=2 max=2 integer ascending)

	*Check whether "group" variable is in proper format
	qui levelsof `groupvar', local(gr)
	local gg=0
	foreach i of local gr {
		if(`i'!=`gg'  | `gg'>1) {
			di in red "The group variable should be 0/1"
			exit 198
		}
		local ++gg
	}
	
	*sample selection
	marksample touse

	*run model for each round and each group
	qui foreach i of local timepts {
		levelsof `groupvar', local(gr)
		foreach j of local gr {
			regress `varlist' [pw `exp'] if `touse' & `timevar'==`i' & `groupvar'==`j', robust
			devcon , groups(head_edu_dum1-head_edu_dum5, max_edu_dum1-max_edu_dum5, zone_dum1-zone_dum6)
			estimates store m_`j'_`i'
		}
		regress `varlist' `groupvar' [pw `exp'] if `touse' & `timevar'==`i', robust
			devcon , groups(head_edu_dum1-head_edu_dum5, max_edu_dum1-max_edu_dum5, zone_dum1-zone_dum6)
			estimates store m_pooled_`i'

	}

smithwelch m_0_38 m_1_38 m_0_61 m_1_61, benchmark(1) reference(m_pooled_38 m_pooled_61) adjust(`groupvar') detail(edu_all=head_edu_dum* max_edu_dum*, zone_dum=zone_dum*) 

	
	//ereturn
*clear all e() first
ereturn clear

	
 matrix D = r(D)
 matrix DD = r(DD)
 *Sample 1
 ereturn scalar edu_dum_e1=el(D,1,2)
 ereturn scalar quota_scst_e1=el(D,7,2)
 ereturn scalar total_d1=el(D,9,1)
 ereturn scalar total_e1=el(D,9,2)
 ereturn scalar total_c1=el(D,9,3)
 
 *Sample 2
 ereturn scalar edu_dum_e2=el(D,1,6)
 ereturn scalar occ_one_e2=el(D,7,6)
 ereturn scalar total_d2=el(D,9,5)
 ereturn scalar total_e2=el(D,9,6)
 ereturn scalar total_c2=el(D,9,7)
 
*Sample 2 minus Sample 1
 matrix AA = D[1...,"s2:"]-D[1...,"s1:"] 	
 ereturn scalar edu_dum_de=el(AA,1,2)
 ereturn scalar occ_one_de=el(AA,7,2)
 ereturn scalar total_dd=el(AA,9,1)
 ereturn scalar total_de=el(AA,9,2)
 ereturn scalar total_dc=el(AA,9,3)

 *Decomp of dE
 ereturn scalar edu_dum_de_e=el(DD,1,2)
 ereturn scalar occ_one_de_e=el(DD,7,2)
 ereturn scalar total_de_d=el(DD,9,1)
 ereturn scalar total_de_e=el(DD,9,2)
 ereturn scalar total_de_c=el(DD,9,3)
 
end


*** ====================================================================================================================

			* RIF WAGES
capture program drop mysmithwelchrif
program mysmithwelchrif, eclass properties(svyb)
	version 11
	syntax varlist [pweight iweight] [if] [in], GROUPvar(varname numeric) TIMEvar(varname numeric) TIMEPTs(numlist min=2 max=2 integer ascending) Quantile(real)

	*Check whether "group" variable is in proper format
	levelsof `groupvar', local(gr)
	local gg=0
	foreach i of local gr {
		if(`i'!=`gg'  | `gg'>1) {
			di in red "The group variable should be 0/1"
			exit 198
		}
		local ++gg
	}
	
	*sample selection
	marksample touse

	*run model for each round and each group
	qui foreach i of local timepts {
		levelsof `groupvar', local(gr)
		foreach j of local gr {
			rifreg `varlist' [aw `exp'] if `touse' & `timevar'==`i' & `groupvar'==`j', quantile(`quantile') // re(rif_`j'_`i')
			devcon , groups(edu_dum1-edu_dum5, zone_dum1-zone_dum6) 
			estimates store m_`j'_`i'
		}
		rifreg `varlist' `groupvar' [aw `exp'] if `touse' & `timevar'==`i', quantile(`quantile') // re(rif_pooled_`i')
		devcon , groups(edu_dum1-edu_dum5, zone_dum1-zone_dum6)  
		estimates store m_pooled_`i'

	}

smithwelch m_0_38 m_1_38 m_0_61 m_1_61, benchmark(1) reference(m_pooled_38 m_pooled_61) adjust(`groupvar') detail(age_both=age age2, edu_dum=edu_dum*, zone_dum=zone_dum*) 


	
	//ereturn
*clear all e() first
ereturn clear

	
 matrix D = r(D)
 matrix DD = r(DD)
 *Sample 1
 ereturn scalar edu_dum_e1=el(D,2,2)
 ereturn scalar quota_scst_e1=el(D,6,2)
 ereturn scalar total_d1=el(D,8,1)
 ereturn scalar total_e1=el(D,8,2)
 ereturn scalar total_c1=el(D,8,3)
 
 *Sample 2
 ereturn scalar edu_dum_e2=el(D,2,6)
 ereturn scalar quota_scst_e2=el(D,6,6)
 ereturn scalar total_d2=el(D,8,5)
 ereturn scalar total_e2=el(D,8,6)
 ereturn scalar total_c2=el(D,8,7)
 
*Sample 2 minus Sample 1
 matrix AA = D[1...,"s2:"]-D[1...,"s1:"] 	
 ereturn scalar edu_dum_de=el(AA,2,2)
 ereturn scalar quota_scst_de=el(AA,6,2)
 ereturn scalar total_dd=el(AA,8,1)
 ereturn scalar total_de=el(AA,8,2)
 ereturn scalar total_dc=el(AA,8,3)

 *Decomp of dE
 ereturn scalar edu_dum_de_e=el(DD,2,2)
 ereturn scalar quota_scst_de_e=el(DD,6,2)
 ereturn scalar total_de_d=el(DD,8,1)
 ereturn scalar total_de_e=el(DD,8,2)
 ereturn scalar total_de_c=el(DD,8,3)
 

end


*** ====================================================================================================================

			* RIF CONSUMPTION
capture program drop mysmithwelchrifC
program mysmithwelchrifC, eclass properties(svyb)
	version 11
	syntax varlist [pweight iweight] [if] [in], GROUPvar(varname numeric) TIMEvar(varname numeric) TIMEPTs(numlist min=2 max=2 integer ascending) Quantile(real)

	*Check whether "group" variable is in proper format
	levelsof `groupvar', local(gr)
	local gg=0
	foreach i of local gr {
		if(`i'!=`gg'  | `gg'>1) {
			di in red "The group variable should be 0/1"
			exit 198
		}
		local ++gg
	}
	
	*sample selection
	marksample touse

	*run model for each round and each group
	qui foreach i of local timepts {
		levelsof `groupvar', local(gr)
		foreach j of local gr {
			rifreg `varlist' [aw `exp'] if `touse' & `timevar'==`i' & `groupvar'==`j', quantile(`quantile') // re(rif_`j'_`i')
			devcon , groups(head_edu_dum1-head_edu_dum5, max_edu_dum1-max_edu_dum5, zone_dum1-zone_dum6)
			estimates store m_`j'_`i'
		}
		rifreg `varlist' `groupvar' [aw `exp'] if `touse' & `timevar'==`i', quantile(`quantile') // re(rif_pooled_`i')
		devcon , groups(head_edu_dum1-head_edu_dum5, max_edu_dum1-max_edu_dum5, zone_dum1-zone_dum6)
		estimates store m_pooled_`i'

	}

smithwelch m_0_38 m_1_38 m_0_61 m_1_61, benchmark(1) reference(m_pooled_38 m_pooled_61) adjust(`groupvar') detail(edu_all=head_edu_dum* max_edu_dum*, zone_dum=zone_dum*) 


	//ereturn
*clear all e() first
ereturn clear

	
 matrix D = r(D)
 matrix DD = r(DD)
 *Sample 1
 ereturn scalar edu_dum_e1=el(D,1,2)
 ereturn scalar quota_scst_e1=el(D,7,2)
 ereturn scalar total_d1=el(D,9,1)
 ereturn scalar total_e1=el(D,9,2)
 ereturn scalar total_c1=el(D,9,3)
 
 *Sample 2
 ereturn scalar edu_dum_e2=el(D,1,6)
 ereturn scalar quota_scst_e2=el(D,7,6)
 ereturn scalar total_d2=el(D,9,5)
 ereturn scalar total_e2=el(D,9,6)
 ereturn scalar total_c2=el(D,9,7)
 
*Sample 2 minus Sample 1
 matrix AA = D[1...,"s2:"]-D[1...,"s1:"] 	
 ereturn scalar edu_dum_de=el(AA,1,2)
 ereturn scalar quota_scst_de=el(AA,7,2)
 ereturn scalar total_dd=el(AA,9,1)
 ereturn scalar total_de=el(AA,9,2)
 ereturn scalar total_dc=el(AA,9,3)

 *Decomp of dE
 ereturn scalar edu_dum_de_e=el(DD,1,2)
 ereturn scalar quota_scst_de_e=el(DD,7,2)
 ereturn scalar total_de_d=el(DD,9,1)
 ereturn scalar total_de_e=el(DD,9,2)
 ereturn scalar total_de_c=el(DD,9,3)
 

end

log close


